package data

import (
	"context"
	"git.oa00.com/supply-chain/service/client"
	"git.oa00.com/supply-chain/service/lib/bean"
	"github.com/shopspring/decimal"
)

type afs struct {
}

type ArgsAfsLists struct {
	StartFinishAt string
	EndFinishAt   string
	Page          bean.Page
}

type ReplyAfsLists struct {
	Lists []AfsItem `json:"lists"`
	Total int64     `json:"total"`
}

type AfsItem struct {
	SourceName     string          `json:"sourceName"`     // 供应渠道
	SourceSonName  string          `json:"sourceSonName"`  // 供应商
	CustomerName   string          `json:"customerName"`   // 客户名
	AfsSn          string          `json:"afsSn"`          // 售后单号
	AfsResult      string          `json:"afsResult"`      // 售后处理结果
	AfsFinishAt    int64           `json:"afsFinishAt"`    // 售后完成时间
	OrderSn        string          `json:"orderSn"`        // 原始订单号
	OrderSunSn     string          `json:"orderSunSn"`     // 订单号
	LadingBillAt   int64           `json:"ladingBillAt"`   // 订单支付时间
	FinishAt       int64           `json:"finishAt"`       // 确认收货时间
	SkuName        string          `json:"skuName"`        // 商品名称
	SkuUpcCode     string          `json:"skuUpcCode"`     // 商品条码
	Unit           string          `json:"unit"`           // 单位
	AfsQuality     uint            `json:"afsQuality"`     // 售后数量
	NewOrderSn     string          `json:"newOrderSn"`     // 新订单号
	PlatformRefund decimal.Decimal `json:"platformRefund"` // 平台退款金额
	SupplierRefund decimal.Decimal `json:"supplierRefund"` // 供应商退款金额
}

// AfsLists @Title 售后明细列表
func (a *afs) AfsLists(ctx context.Context, args ArgsAfsLists) (reply ReplyAfsLists, err error) {
	xClient, err := client.GetClient(a)
	if err != nil {
		return
	}
	err = xClient.Call(ctx, "AfsLists", args, &reply)
	return
}
